Log In to Canvas

Skip To Content My Dashboard
Close

# Canvas

## Log In

Username Password
Stay signed in
Don't know your password?

Enter your Username and we'll send you a link to change your password.

Username
← Back to Login
In order to create video or audio recordings your computer needs to be webcam-enabled. If you don't have a webcam on your computer, you can still record audio-only messages by first installing the Google Video Chat plugin.
Install the Video Plugin
Don't have a webcam?